#!/bin/sh
#
# Source: http://www.linux1394.org/dl/libiec61883-1.2.0.tar.gz
#
# Packager : gmg (g.monpontet@gmail.com)
# 

#------------------Set Some Variables

soft='libiec61883'
softversion='1.2.0'
packageversion='64.1'

arch='i486'
cpu='i686'

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tar.gz
rm -rf $dest

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
         |-----handy-ruler------------------------------------------------------|
libiec61883: libiec61883 (This library is an implementation of IEC 61883)
libiec61883:
libiec61883: This library is an implementation of IEC 61883, part 1 (CIP, plug
libiec61883: registers, and CMP), part 2 (DV-SD), part 4 (MPEG2-TS), and part 6
libiec61883: (AMDTP). Outside of IIDC, nearly all FireWire multimedia devices
libiec61883: use IEC 61883 protocols.
libiec61883:
libiec61883:
libiec61883:
libiec61883:
libiec61883:
EODESC

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" 

./configure \
  --prefix=/usr \
  --mandir=/usr/man \
  --disable-static
make
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

find $dest/usr/man -type f -exec gzip -9 {} \;

#-------------------Prepare the documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a AUTHORS ChangeLog COPYING INSTALL NEWS README $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

           |-----handy-ruler------------------------------------------------------|
libiec61883: libiec61883 (This library is an implementation of IEC 61883)
libiec61883:
libiec61883: This library is an implementation of IEC 61883, part 1 (CIP, plug
libiec61883: registers, and CMP), part 2 (DV-SD), part 4 (MPEG2-TS), and part 6
libiec61883: (AMDTP). Outside of IIDC, nearly all FireWire multimedia devices
libiec61883: use IEC 61883 protocols.
libiec61883:
libiec61883:
libiec61883:
libiec61883:
libiec61883:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5